@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) Duncan Macleod (2013)
+# Copyright (C) Duncan Macleod (2014-2019)
 #
 # This file is part of GWpy.
 #
@@ -49,20 +49,19 @@ def new_table(tablename, data=None, **new_kw):
 @pytest.fixture
 def llwtable():
     from glue.ligolw.ligolw import (Document, LIGO_LW)
-    from glue.ligolw import lsctables
 
     # build dummy document with two tables
     xmldoc = Document()
     llw = xmldoc.appendChild(LIGO_LW())
     tables = [new_table('process'), new_table('sngl_ringdown')]
-    names = [t.TableName(t.Name) for t in tables]
-    [llw.appendChild(t) for t in tables]  # add tables to xmldoc
+    for t in tables:
+        llw.appendChild(t)
     return xmldoc
 
 
 @skip_missing_dependency('glue.ligolw.lsctables')  # check for LAL
 def test_open_xmldoc(llwtable):
-    from glue.ligolw.ligolw import (Document, LIGO_LW)
+    from glue.ligolw.ligolw import Document
     assert isinstance(io_ligolw.open_xmldoc(tempfile.mktemp()), Document)
 
     with tempfile.TemporaryFile(mode='w') as f:
